PixoJpegOptions class

JPEG encoding options (domain model).

Constructors

PixoJpegOptions({required int width, required int height, int colorType = 2, int quality = 85, int preset = 1, bool subsampling420 = true})
const

Properties

colorType int
Color type: 0=Gray, 2=Rgb.
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
preset int
Preset: 0=fast, 1=balanced, 2=max.
final
quality int
Quality 1-100.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subsampling420 bool
If true, use 4:2:0 subsampling; otherwise 4:4:4.
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited